/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 *
 **************************************************************************
gPXE -  Network Bootstrap Program

Literature dealing with the network protocols:
	ARP - RFC826
	RARP - RFC903
	UDP - RFC768
	BOOTP - RFC951, RFC2132 (vendor extensions)
	DHCP - RFC2131, RFC2132 (options)
	TFTP - RFC1350, RFC2347 (options), RFC2348 (blocksize), RFC2349 (tsize)
	RPC - RFC1831, RFC1832 (XDR), RFC1833 (rpcbind/portmapper)
	NFS - RFC1094, RFC1813 (v3, useful for clarifications, not implemented)
	IGMP - RFC1112

**************************************************************************/

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <gpxe/init.h>
#include <gpxe/banner.h>
#include <gpxe/features.h>
#include <gpxe/shell.h>
#include <gpxe/image.h>
#include <gpxe/keys.h>
#include <usr/prompt.h>
#include <usr/autoboot.h>
#include <config/general.h>

#include <gpxe/settings.h>

#if ! (defined(SHELL_HIDE) || defined(SHELL_DISABLE))
/**
 * Prompt for shell entry
 *
 * @ret	enter_shell		User wants to enter shell
 */
static int shell_banner ( void ) {

	/* Skip prompt if timeout is zero */
	if ( BANNER_TIMEOUT <= 0 )
		return 0;

	return ( prompt ( "\nPress Ctrl-B for the gPXE command line...",
			  ( BANNER_TIMEOUT * 100 ), CTRL_B ) == 0 );
}
#endif

/**
 * Main entry point
 *
 * @ret rc		Return status code
 */
__asmcall int main ( void ) {
	initialise();
	startup();

	welcome();

#if defined(SHELL_HIDE) || defined(SHELL_DISABLE)
	/* OKTL code: use sf_autoboot() */
	/* autoboot(); */
	sf_autoboot();

	/* Pause briefly so that we can see any error messages */
	mdelay(5000);
#else
	/* Prompt for shell */
	if ( shell_banner() ) {
		/* User wants shell; just give them a shell */
		shell();
	} else {
		struct image *image;

		/* User doesn't want shell; load and execute the first
		 * image, or autoboot() if we have no images.  If
		 * booting fails for any reason, offer a second chance
		 * to enter the shell for diagnostics.
		 */
		if ( have_images() ) {
			for_each_image ( image ) {
				image_exec ( image );
				break;
			}
		} else {
			sf_autoboot();
		}

		if ( shell_banner() )
			shell();
	}
#endif

	shutdown_exit();

	return 0;
}
