/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * Driver for Solarflare network controllers and boards
 * Copyright 2019 Solarflare Communications Inc.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, incorporated herein by reference.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _SFCONFIG_MAIN_H
#define _SFCONFIG_MAIN_H

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <stdio.h>
#include <string.h>
#include <curses.h>
#include <gpxe/netdevice.h>
#include <gpxe/sf_widgets.h>
#include <gpxe/dyncfg.h>

enum sf_screen { MENU,
#ifdef BCV_PROTO_ISCSI
		 ISCSI, ISCSI_TARGET, ISCSI_INIT, ISCSI_CHAP,
#endif
		 GLOBAL, PF, RESCUE, NUM_SCREENS,
#ifdef BCV_PROTO_ISCSI
		 _ISCSI_MPIO /* Special entry outside of normal screen array */
#endif
};
enum sf_settings { BOOTROM, DYNAMIC_CONFIG, NUM_SETTINGS };

extern struct netdev_conf *all_netdevs;

/* A list of information for each net_dev in sfconfig() */
struct netdev_conf {
	struct net_device	*netdev;
	struct settings		*settings[NUM_SETTINGS];
	sf_widget		*screens[NUM_SCREENS];
	int			dirty;
	int			nicnum;
	int			port;
	int			pf_index;
	int			writable_settings;

	/* VPD cache */
	char			vpd_id[64];
	char			vpd_fw_ver[MAX_VPD_V0];

	/* Main Screen */
	sf_button		*main_entry;

	/* Global settings */
	sf_combo		*boottype;
	sf_combo		*_bootimage;
	sf_combo		*fw_variant;
	unsigned int		port_modes;

#ifdef BCV_PROTO_ISCSI
	/* iSCSI Initiator */
	sf_checkbox		*initiator_dhcp;
	sf_editbox		*initiator_ip;
	sf_editbox		*initiator_subnet;
	sf_editbox		*initiator_gateway;

	/* iSCSI target */
	sf_checkbox		*target_dhcp;
	sf_editbox		*target_name_edt;
	sf_editbox		*target_server_edt;
	sf_editbox		*target_port_edt;
	sf_editbox		*target_lun_edt;
#endif

	/* Link configuration */
	struct netdev_conf	*link_ctrl_conf;
	sf_combo		*link_speed_combo;

#ifdef BCV_PROTO_ISCSI
	/* MPIO configuration */
	sf_row			*mpio_row;
#endif
};

#define for_each_conf( _conf )						\
	for ( ( _conf ) = all_netdevs;					\
	      ( _conf ) && ( _conf )->netdev != NULL;			\
	      ++( _conf ) )

#define for_each_iscsi_conf( _conf )					\
	for_each_settings_conf ( _conf )				\
		if ( ! sf_conf_is_iscsi ( conf ) )			\
			continue;					\
		else

#define for_each_settings_conf( _conf )					\
	for ( ( _conf ) = all_netdevs;					\
	     ( _conf )->netdev != NULL;					\
	     ++( _conf ) )						\
		if ( ( _conf )->settings[BOOTROM] == NULL )		\
			continue;					\
		else

#define for_each_settings( _conf , _settings )				\
	for ( ( _settings ) = ( _conf )->settings;			\
	      ( _settings ) < ( _conf )->settings + NUM_SETTINGS;	\
	      ++( _settings ) )						\
		if ( ! *( _settings ) )				\
			continue;					\
		else

extern void sf_gdbstub ( void );

extern int sfconfig_run ( void );

#endif /* _SFCONFIG_MAIN_H */
